# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _wavelet_swig
else:
    import _wavelet_swig

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)



def high_res_timer_now() -> "gr::high_res_timer_type":
    r"""high_res_timer_now() -> gr::high_res_timer_type"""
    return _wavelet_swig.high_res_timer_now()

def high_res_timer_now_perfmon() -> "gr::high_res_timer_type":
    r"""high_res_timer_now_perfmon() -> gr::high_res_timer_type"""
    return _wavelet_swig.high_res_timer_now_perfmon()

def high_res_timer_tps() -> "gr::high_res_timer_type":
    r"""high_res_timer_tps() -> gr::high_res_timer_type"""
    return _wavelet_swig.high_res_timer_tps()

def high_res_timer_epoch() -> "gr::high_res_timer_type":
    r"""high_res_timer_epoch() -> gr::high_res_timer_type"""
    return _wavelet_swig.high_res_timer_epoch()
class squash_ff(object):
    r"""Proxy of C++ gr::wavelet::squash_ff class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make(igrid: "pmt_vector_float", ogrid: "pmt_vector_float") -> "gr::wavelet::squash_ff::sptr":
        r"""make(pmt_vector_float igrid, pmt_vector_float ogrid) -> squash_ff_sptr"""
        return _wavelet_swig.squash_ff_make(igrid, ogrid)
    __swig_destroy__ = _wavelet_swig.delete_squash_ff

# Register squash_ff in _wavelet_swig:
_wavelet_swig.squash_ff_swigregister(squash_ff)

def squash_ff_make(igrid: "pmt_vector_float", ogrid: "pmt_vector_float") -> "gr::wavelet::squash_ff::sptr":
    r"""squash_ff_make(pmt_vector_float igrid, pmt_vector_float ogrid) -> squash_ff_sptr"""
    return _wavelet_swig.squash_ff_make(igrid, ogrid)

class wavelet_ff(object):
    r"""Proxy of C++ gr::wavelet::wavelet_ff class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make(size: "int"=1024, order: "int"=20, forward: "bool"=True) -> "gr::wavelet::wavelet_ff::sptr":
        r"""make(int size=1024, int order=20, bool forward=True) -> wavelet_ff_sptr"""
        return _wavelet_swig.wavelet_ff_make(size, order, forward)
    __swig_destroy__ = _wavelet_swig.delete_wavelet_ff

# Register wavelet_ff in _wavelet_swig:
_wavelet_swig.wavelet_ff_swigregister(wavelet_ff)

def wavelet_ff_make(size: "int"=1024, order: "int"=20, forward: "bool"=True) -> "gr::wavelet::wavelet_ff::sptr":
    r"""wavelet_ff_make(int size=1024, int order=20, bool forward=True) -> wavelet_ff_sptr"""
    return _wavelet_swig.wavelet_ff_make(size, order, forward)

class wvps_ff(object):
    r"""Proxy of C++ gr::wavelet::wvps_ff class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make(ilen: "int") -> "gr::wavelet::wvps_ff::sptr":
        r"""make(int ilen) -> wvps_ff_sptr"""
        return _wavelet_swig.wvps_ff_make(ilen)
    __swig_destroy__ = _wavelet_swig.delete_wvps_ff

# Register wvps_ff in _wavelet_swig:
_wavelet_swig.wvps_ff_swigregister(wvps_ff)

def wvps_ff_make(ilen: "int") -> "gr::wavelet::wvps_ff::sptr":
    r"""wvps_ff_make(int ilen) -> wvps_ff_sptr"""
    return _wavelet_swig.wvps_ff_make(ilen)

class squash_ff_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::wavelet::squash_ff > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(squash_ff_sptr self) -> squash_ff_sptr
        __init__(squash_ff_sptr self, squash_ff p) -> squash_ff_sptr
        """
        _wavelet_swig.squash_ff_sptr_swiginit(self, _wavelet_swig.new_squash_ff_sptr(*args))

    def __deref__(self) -> "gr::wavelet::squash_ff *":
        r"""__deref__(squash_ff_sptr self) -> squash_ff"""
        return _wavelet_swig.squash_ff_sptr___deref__(self)
    __swig_destroy__ = _wavelet_swig.delete_squash_ff_sptr

    def make(self, igrid: "pmt_vector_float", ogrid: "pmt_vector_float") -> "gr::wavelet::squash_ff::sptr":
        r"""make(squash_ff_sptr self, pmt_vector_float igrid, pmt_vector_float ogrid) -> squash_ff_sptr"""
        return _wavelet_swig.squash_ff_sptr_make(self, igrid, ogrid)

    def history(self) -> "unsigned int":
        r"""history(squash_ff_sptr self) -> unsigned int"""
        return _wavelet_swig.squash_ff_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(squash_ff_sptr self, int which, int delay)
        declare_sample_delay(squash_ff_sptr self, unsigned int delay)
        """
        return _wavelet_swig.squash_ff_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(squash_ff_sptr self, int which) -> unsigned int"""
        return _wavelet_swig.squash_ff_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(squash_ff_sptr self, int multiple)"""
        return _wavelet_swig.squash_ff_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(squash_ff_sptr self) -> double"""
        return _wavelet_swig.squash_ff_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(squash_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.squash_ff_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(squash_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.squash_ff_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(squash_ff_sptr self) -> bool"""
        return _wavelet_swig.squash_ff_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(squash_ff_sptr self) -> bool"""
        return _wavelet_swig.squash_ff_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(squash_ff_sptr self, unsigned int which_input) -> uint64_t"""
        return _wavelet_swig.squash_ff_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(squash_ff_sptr self, unsigned int which_output) -> uint64_t"""
        return _wavelet_swig.squash_ff_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(squash_ff_sptr self, std::string level)"""
        return _wavelet_swig.squash_ff_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(squash_ff_sptr self) -> std::string"""
        return _wavelet_swig.squash_ff_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(squash_ff_sptr self, int m)"""
        return _wavelet_swig.squash_ff_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(squash_ff_sptr self)"""
        return _wavelet_swig.squash_ff_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(squash_ff_sptr self) -> bool"""
        return _wavelet_swig.squash_ff_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(squash_ff_sptr self, int m)"""
        return _wavelet_swig.squash_ff_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(squash_ff_sptr self, int i) -> long"""
        return _wavelet_swig.squash_ff_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(squash_ff_sptr self, long max_output_buffer)
        set_max_output_buffer(squash_ff_sptr self, int port, long max_output_buffer)
        """
        return _wavelet_swig.squash_ff_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(squash_ff_sptr self, int i) -> long"""
        return _wavelet_swig.squash_ff_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(squash_ff_sptr self, long min_output_buffer)
        set_min_output_buffer(squash_ff_sptr self, int port, long min_output_buffer)
        """
        return _wavelet_swig.squash_ff_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(squash_ff_sptr self, int which) -> float
        pc_input_buffers_full(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(squash_ff_sptr self, int which) -> float
        pc_input_buffers_full_avg(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(squash_ff_sptr self, int which) -> float
        pc_input_buffers_full_var(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(squash_ff_sptr self, int which) -> float
        pc_output_buffers_full(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(squash_ff_sptr self, int which) -> float
        pc_output_buffers_full_avg(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(squash_ff_sptr self, int which) -> float
        pc_output_buffers_full_var(squash_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.squash_ff_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(squash_ff_sptr self) -> float"""
        return _wavelet_swig.squash_ff_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(squash_ff_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _wavelet_swig.squash_ff_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(squash_ff_sptr self)"""
        return _wavelet_swig.squash_ff_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(squash_ff_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _wavelet_swig.squash_ff_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(squash_ff_sptr self) -> int"""
        return _wavelet_swig.squash_ff_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(squash_ff_sptr self, int priority) -> int"""
        return _wavelet_swig.squash_ff_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(squash_ff_sptr self) -> std::string"""
        return _wavelet_swig.squash_ff_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(squash_ff_sptr self) -> std::string"""
        return _wavelet_swig.squash_ff_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(squash_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.squash_ff_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(squash_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.squash_ff_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(squash_ff_sptr self) -> long"""
        return _wavelet_swig.squash_ff_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(squash_ff_sptr self) -> basic_block_sptr"""
        return _wavelet_swig.squash_ff_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(squash_ff_sptr self, int ninputs, int noutputs) -> bool"""
        return _wavelet_swig.squash_ff_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(squash_ff_sptr self) -> std::string"""
        return _wavelet_swig.squash_ff_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(squash_ff_sptr self, std::string name)"""
        return _wavelet_swig.squash_ff_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(squash_ff_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _wavelet_swig.squash_ff_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(squash_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.squash_ff_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(squash_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.squash_ff_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(squash_ff_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _wavelet_swig.squash_ff_sptr_message_subscribers(self, which_port)

# Register squash_ff_sptr in _wavelet_swig:
_wavelet_swig.squash_ff_sptr_swigregister(squash_ff_sptr)


squash_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
squash_ff = squash_ff.make;

class wavelet_ff_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::wavelet::wavelet_ff > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(wavelet_ff_sptr self) -> wavelet_ff_sptr
        __init__(wavelet_ff_sptr self, wavelet_ff p) -> wavelet_ff_sptr
        """
        _wavelet_swig.wavelet_ff_sptr_swiginit(self, _wavelet_swig.new_wavelet_ff_sptr(*args))

    def __deref__(self) -> "gr::wavelet::wavelet_ff *":
        r"""__deref__(wavelet_ff_sptr self) -> wavelet_ff"""
        return _wavelet_swig.wavelet_ff_sptr___deref__(self)
    __swig_destroy__ = _wavelet_swig.delete_wavelet_ff_sptr

    def make(self, size: "int"=1024, order: "int"=20, forward: "bool"=True) -> "gr::wavelet::wavelet_ff::sptr":
        r"""make(wavelet_ff_sptr self, int size=1024, int order=20, bool forward=True) -> wavelet_ff_sptr"""
        return _wavelet_swig.wavelet_ff_sptr_make(self, size, order, forward)

    def history(self) -> "unsigned int":
        r"""history(wavelet_ff_sptr self) -> unsigned int"""
        return _wavelet_swig.wavelet_ff_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(wavelet_ff_sptr self, int which, int delay)
        declare_sample_delay(wavelet_ff_sptr self, unsigned int delay)
        """
        return _wavelet_swig.wavelet_ff_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(wavelet_ff_sptr self, int which) -> unsigned int"""
        return _wavelet_swig.wavelet_ff_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(wavelet_ff_sptr self, int multiple)"""
        return _wavelet_swig.wavelet_ff_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(wavelet_ff_sptr self) -> double"""
        return _wavelet_swig.wavelet_ff_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(wavelet_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.wavelet_ff_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(wavelet_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.wavelet_ff_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(wavelet_ff_sptr self) -> bool"""
        return _wavelet_swig.wavelet_ff_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(wavelet_ff_sptr self) -> bool"""
        return _wavelet_swig.wavelet_ff_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(wavelet_ff_sptr self, unsigned int which_input) -> uint64_t"""
        return _wavelet_swig.wavelet_ff_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(wavelet_ff_sptr self, unsigned int which_output) -> uint64_t"""
        return _wavelet_swig.wavelet_ff_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(wavelet_ff_sptr self, std::string level)"""
        return _wavelet_swig.wavelet_ff_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(wavelet_ff_sptr self) -> std::string"""
        return _wavelet_swig.wavelet_ff_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(wavelet_ff_sptr self, int m)"""
        return _wavelet_swig.wavelet_ff_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(wavelet_ff_sptr self)"""
        return _wavelet_swig.wavelet_ff_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(wavelet_ff_sptr self) -> bool"""
        return _wavelet_swig.wavelet_ff_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(wavelet_ff_sptr self, int m)"""
        return _wavelet_swig.wavelet_ff_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(wavelet_ff_sptr self, int i) -> long"""
        return _wavelet_swig.wavelet_ff_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(wavelet_ff_sptr self, long max_output_buffer)
        set_max_output_buffer(wavelet_ff_sptr self, int port, long max_output_buffer)
        """
        return _wavelet_swig.wavelet_ff_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(wavelet_ff_sptr self, int i) -> long"""
        return _wavelet_swig.wavelet_ff_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(wavelet_ff_sptr self, long min_output_buffer)
        set_min_output_buffer(wavelet_ff_sptr self, int port, long min_output_buffer)
        """
        return _wavelet_swig.wavelet_ff_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(wavelet_ff_sptr self, int which) -> float
        pc_input_buffers_full(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(wavelet_ff_sptr self, int which) -> float
        pc_input_buffers_full_avg(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(wavelet_ff_sptr self, int which) -> float
        pc_input_buffers_full_var(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(wavelet_ff_sptr self, int which) -> float
        pc_output_buffers_full(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(wavelet_ff_sptr self, int which) -> float
        pc_output_buffers_full_avg(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(wavelet_ff_sptr self, int which) -> float
        pc_output_buffers_full_var(wavelet_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wavelet_ff_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(wavelet_ff_sptr self) -> float"""
        return _wavelet_swig.wavelet_ff_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(wavelet_ff_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _wavelet_swig.wavelet_ff_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(wavelet_ff_sptr self)"""
        return _wavelet_swig.wavelet_ff_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(wavelet_ff_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _wavelet_swig.wavelet_ff_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(wavelet_ff_sptr self) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(wavelet_ff_sptr self, int priority) -> int"""
        return _wavelet_swig.wavelet_ff_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(wavelet_ff_sptr self) -> std::string"""
        return _wavelet_swig.wavelet_ff_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(wavelet_ff_sptr self) -> std::string"""
        return _wavelet_swig.wavelet_ff_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(wavelet_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.wavelet_ff_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(wavelet_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.wavelet_ff_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(wavelet_ff_sptr self) -> long"""
        return _wavelet_swig.wavelet_ff_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(wavelet_ff_sptr self) -> basic_block_sptr"""
        return _wavelet_swig.wavelet_ff_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(wavelet_ff_sptr self, int ninputs, int noutputs) -> bool"""
        return _wavelet_swig.wavelet_ff_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(wavelet_ff_sptr self) -> std::string"""
        return _wavelet_swig.wavelet_ff_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(wavelet_ff_sptr self, std::string name)"""
        return _wavelet_swig.wavelet_ff_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(wavelet_ff_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _wavelet_swig.wavelet_ff_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(wavelet_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.wavelet_ff_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(wavelet_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.wavelet_ff_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(wavelet_ff_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _wavelet_swig.wavelet_ff_sptr_message_subscribers(self, which_port)

# Register wavelet_ff_sptr in _wavelet_swig:
_wavelet_swig.wavelet_ff_sptr_swigregister(wavelet_ff_sptr)


wavelet_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
wavelet_ff = wavelet_ff.make;

class wvps_ff_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::wavelet::wvps_ff > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(wvps_ff_sptr self) -> wvps_ff_sptr
        __init__(wvps_ff_sptr self, wvps_ff p) -> wvps_ff_sptr
        """
        _wavelet_swig.wvps_ff_sptr_swiginit(self, _wavelet_swig.new_wvps_ff_sptr(*args))

    def __deref__(self) -> "gr::wavelet::wvps_ff *":
        r"""__deref__(wvps_ff_sptr self) -> wvps_ff"""
        return _wavelet_swig.wvps_ff_sptr___deref__(self)
    __swig_destroy__ = _wavelet_swig.delete_wvps_ff_sptr

    def make(self, ilen: "int") -> "gr::wavelet::wvps_ff::sptr":
        r"""make(wvps_ff_sptr self, int ilen) -> wvps_ff_sptr"""
        return _wavelet_swig.wvps_ff_sptr_make(self, ilen)

    def history(self) -> "unsigned int":
        r"""history(wvps_ff_sptr self) -> unsigned int"""
        return _wavelet_swig.wvps_ff_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(wvps_ff_sptr self, int which, int delay)
        declare_sample_delay(wvps_ff_sptr self, unsigned int delay)
        """
        return _wavelet_swig.wvps_ff_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(wvps_ff_sptr self, int which) -> unsigned int"""
        return _wavelet_swig.wvps_ff_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(wvps_ff_sptr self, int multiple)"""
        return _wavelet_swig.wvps_ff_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(wvps_ff_sptr self) -> double"""
        return _wavelet_swig.wvps_ff_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(wvps_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.wvps_ff_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(wvps_ff_sptr self) -> uint64_t"""
        return _wavelet_swig.wvps_ff_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(wvps_ff_sptr self) -> bool"""
        return _wavelet_swig.wvps_ff_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(wvps_ff_sptr self) -> bool"""
        return _wavelet_swig.wvps_ff_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(wvps_ff_sptr self, unsigned int which_input) -> uint64_t"""
        return _wavelet_swig.wvps_ff_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(wvps_ff_sptr self, unsigned int which_output) -> uint64_t"""
        return _wavelet_swig.wvps_ff_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(wvps_ff_sptr self, std::string level)"""
        return _wavelet_swig.wvps_ff_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(wvps_ff_sptr self) -> std::string"""
        return _wavelet_swig.wvps_ff_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(wvps_ff_sptr self, int m)"""
        return _wavelet_swig.wvps_ff_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(wvps_ff_sptr self)"""
        return _wavelet_swig.wvps_ff_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(wvps_ff_sptr self) -> bool"""
        return _wavelet_swig.wvps_ff_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(wvps_ff_sptr self, int m)"""
        return _wavelet_swig.wvps_ff_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(wvps_ff_sptr self, int i) -> long"""
        return _wavelet_swig.wvps_ff_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(wvps_ff_sptr self, long max_output_buffer)
        set_max_output_buffer(wvps_ff_sptr self, int port, long max_output_buffer)
        """
        return _wavelet_swig.wvps_ff_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(wvps_ff_sptr self, int i) -> long"""
        return _wavelet_swig.wvps_ff_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(wvps_ff_sptr self, long min_output_buffer)
        set_min_output_buffer(wvps_ff_sptr self, int port, long min_output_buffer)
        """
        return _wavelet_swig.wvps_ff_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(wvps_ff_sptr self, int which) -> float
        pc_input_buffers_full(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(wvps_ff_sptr self, int which) -> float
        pc_input_buffers_full_avg(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(wvps_ff_sptr self, int which) -> float
        pc_input_buffers_full_var(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(wvps_ff_sptr self, int which) -> float
        pc_output_buffers_full(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(wvps_ff_sptr self, int which) -> float
        pc_output_buffers_full_avg(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(wvps_ff_sptr self, int which) -> float
        pc_output_buffers_full_var(wvps_ff_sptr self) -> pmt_vector_float
        """
        return _wavelet_swig.wvps_ff_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(wvps_ff_sptr self) -> float"""
        return _wavelet_swig.wvps_ff_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(wvps_ff_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _wavelet_swig.wvps_ff_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(wvps_ff_sptr self)"""
        return _wavelet_swig.wvps_ff_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(wvps_ff_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _wavelet_swig.wvps_ff_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(wvps_ff_sptr self) -> int"""
        return _wavelet_swig.wvps_ff_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(wvps_ff_sptr self, int priority) -> int"""
        return _wavelet_swig.wvps_ff_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(wvps_ff_sptr self) -> std::string"""
        return _wavelet_swig.wvps_ff_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(wvps_ff_sptr self) -> std::string"""
        return _wavelet_swig.wvps_ff_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(wvps_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.wvps_ff_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(wvps_ff_sptr self) -> io_signature_sptr"""
        return _wavelet_swig.wvps_ff_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(wvps_ff_sptr self) -> long"""
        return _wavelet_swig.wvps_ff_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(wvps_ff_sptr self) -> basic_block_sptr"""
        return _wavelet_swig.wvps_ff_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(wvps_ff_sptr self, int ninputs, int noutputs) -> bool"""
        return _wavelet_swig.wvps_ff_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(wvps_ff_sptr self) -> std::string"""
        return _wavelet_swig.wvps_ff_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(wvps_ff_sptr self, std::string name)"""
        return _wavelet_swig.wvps_ff_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(wvps_ff_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _wavelet_swig.wvps_ff_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(wvps_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.wvps_ff_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(wvps_ff_sptr self) -> swig_pmt_ptr"""
        return _wavelet_swig.wvps_ff_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(wvps_ff_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _wavelet_swig.wvps_ff_sptr_message_subscribers(self, which_port)

# Register wvps_ff_sptr in _wavelet_swig:
_wavelet_swig.wvps_ff_sptr_swigregister(wvps_ff_sptr)


wvps_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
wvps_ff = wvps_ff.make;



